.. _aboutyt:

About yt
========

.. contents::
   :depth: 1
   :local:
   :backlinks: none

What is yt?
-----------

yt is a toolkit for analyzing and visualizing quantitative data.  Originally
written to analyze 3D grid-based astrophysical simulation data,
it has grown to handle any kind of data represented in a 2D or 3D volume.
yt is an Python-based open source project and is open for anyone to use or
contribute code.  The entire source code and history is available to all
at https://github.com/yt-project/yt .

.. _who-is-yt:

Who is yt?
----------

As an open-source project, yt has a large number of user-developers.
In September of 2014, the yt developer community collectively decided to endow
the title of *member* on individuals who had contributed in a significant way
to the project.  For a list of those members and a description of their
contributions to the code, see
`our members website. <https://yt-project.org/members.html>`_

History of yt
-------------

yt was originally created to study datasets generated by cosmological
simulations of galaxy and star formation conducted by the simulation code Enzo.
After expanding to address data output by other simulation platforms, it further
broadened to include alternate, grid-free methods of simulating -- particularly,
particles and unstructured meshes.

With the release of yt 4.0, we are proud that the community has continued to
expand, that yt continues to participate in the broader ecosystem, and that the
development process is continuing to improve in both inclusivity and openness.

For a more personal retrospective by the original author, Matthew Turk, you can
see this `blog post from
2017 <https://medium.com/@matthewturk/10-years-of-yt-c93b2f1cef8c>`_.

How do I contact yt?
--------------------

If you have any questions about the code, please contact the `yt users email
list <https://mail.python.org/archives/list/yt-users@python.org/>`_.  If
you're having other problems, please follow the steps in
:ref:`asking-for-help`, particularly including Slack and GitHub issues.

How do I cite yt?
-----------------

If you use yt in a publication, we'd very much appreciate a citation!  You
should feel free to cite the `ApJS paper
<https://ui.adsabs.harvard.edu/abs/2011ApJS..192....9T>`_ with the following BibTeX
entry: ::

   @ARTICLE{2011ApJS..192....9T,
      author = {{Turk}, M.~J. and {Smith}, B.~D. and {Oishi}, J.~S. and {Skory}, S. and
   	{Skillman}, S.~W. and {Abel}, T. and {Norman}, M.~L.},
       title = "{yt: A Multi-code Analysis Toolkit for Astrophysical Simulation Data}",
     journal = {The Astrophysical Journal Supplement Series},
   archivePrefix = "arXiv",
      eprint = {1011.3514},
    primaryClass = "astro-ph.IM",
    keywords = {cosmology: theory, methods: data analysis, methods: numerical },
        year = 2011,
       month = jan,
      volume = 192,
         eid = {9},
       pages = {9},
         doi = {10.1088/0067-0049/192/1/9},
      adsurl = {https://ui.adsabs.harvard.edu/abs/2011ApJS..192....9T},
     adsnote = {Provided by the SAO/NASA Astrophysics Data System}
   }

While this paper is somewhat out of date -- and certainly does not include the
appropriate list of authors -- we are preparing a new method paper as well as
preparing a new strategy for ensuring equal credit distribution for
contributors.  Some of this work can be found at the `yt-4.0-paper
<https://github.com/yt-project/yt-4.0-paper/>`_ repository.
